Stan Math Library: stan/math/prim/mat/prob/dirichlet_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
dirichlet_rng.hpp File Reference
`#include <boost/math/special_functions/gamma.hpp>`
`#include <boost/random/gamma_distribution.hpp>`
`#include <boost/random/uniform_real_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/scal/err/check_consistent_sizes.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/mat/err/check_simplex.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/mat/fun/log_sum_exp.hpp>`
`#include <stan/math/prim/scal/fun/multiply_log.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <cmath>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
Eigen::VectorXd | stan::math::dirichlet_rng (const Eigen::Matrix< double, Eigen::Dynamic, 1 > &alpha, RNG &rng)
| Return a draw from a Dirichlet distribution with specified parameters and pseudo-random number generator. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.